@@ -744,6 +744,32 @@ should_mount_be_ignored (GduPool *pool, GduDevice *d)
   return ret;
 }
 
+gboolean
+_is_pc_floppy_drive (GduDevice *device)
+{
+  gboolean ret;
+  gchar **drive_media_compat;
+  const gchar *drive_connection_interface;
+
+  ret = FALSE;
+
+  if (device != NULL)
+    {
+      drive_media_compat = gdu_device_drive_get_media_compatibility (device);
+      drive_connection_interface = gdu_device_drive_get_connection_interface (device);
+
+      if (g_strcmp0 (drive_connection_interface, "platform") == 0 &&
+          (drive_media_compat != NULL &&
+           g_strv_length (drive_media_compat) > 0 &&
+           g_strcmp0 (drive_media_compat[0], "floppy") == 0))
+        {
+          ret = TRUE;
+        }
+    }
+
+  return ret;
+}
+
 static gboolean
 should_volume_be_ignored (GduPool *pool, GduVolume *volume, GList *fstab_mount_points)
 {
@@ -763,7 +789,7 @@ should_volume_be_ignored (GduPool *pool, GduVolume *volume, GList *fstab_mount_p
   usage = gdu_device_id_get_usage (device);
   type = gdu_device_id_get_type (device);
 
-  if (g_strcmp0 (usage, "filesystem") == 0)
+  if (_is_pc_floppy_drive (device) || g_strcmp0 (usage, "filesystem") == 0)
     {
       GUnixMountPoint *mount_point;
 
@@ -810,7 +836,7 @@ should_drive_be_ignored (GduPool *pool, GduDrive *d, GList *fstab_mount_points)
 {
   GduDevice *device;
   gboolean ignored;
-  gboolean has_volumes;
+  gboolean have_volumes;
   gboolean all_volumes_are_ignored;
   GList *enclosed;
   GList *l;
@@ -821,29 +847,31 @@ should_drive_be_ignored (GduPool *pool, GduDrive *d, GList *fstab_mount_points)
 
   device = gdu_presentable_get_device (GDU_PRESENTABLE (d));
 
-  /* If there is no GduDevice for a drive, then ignore it.
-   *
-   * Note that right now the only drives without a GduDevice are Linux
-   * MD arrays not yet activated. In the future we might want to
-   * display these so the user can start the array.
+  /* If there is no GduDevice for a drive, then ignore it unless
+   * we know how to start it. Right now this is only relevant
+   * for GduLinuxMdDrive but we can add other stuff to libgdu
+   * in the future and things will work here
    */
   if (device == NULL)
     {
-      ignored = TRUE;
-      goto out;
+      if (!gdu_drive_is_activatable (d))
+        {
+          ignored = TRUE;
+          goto out;
+        }
     }
 
-  if (gdu_device_get_presentation_hide (device)) {
+  if (device != NULL && gdu_device_get_presentation_hide (device)) {
     ignored = TRUE;
     goto out;
   }
 
-  has_volumes = FALSE;
+  have_volumes = FALSE;
   all_volumes_are_ignored = TRUE;
 
   /* never ignore a drive if it has volumes that we don't want to ignore */
   enclosed = gdu_pool_get_enclosed_presentables (pool, GDU_PRESENTABLE (d));
-  for (l = enclosed; l != NULL; l = l->next)
+  for (l = enclosed; l != NULL && all_volumes_are_ignored; l = l->next)
     {
       GduPresentable *enclosed_presentable = GDU_PRESENTABLE (l->data);
 
@@ -851,14 +879,53 @@ should_drive_be_ignored (GduPool *pool, GduDrive *d, GList *fstab_mount_points)
       if (GDU_IS_VOLUME (enclosed_presentable))
         {
           GduVolume *volume = GDU_VOLUME (enclosed_presentable);
+          GduDevice *volume_device;
 
-          has_volumes = TRUE;
+          have_volumes = TRUE;
 
           if (!should_volume_be_ignored (pool, volume, fstab_mount_points))
             {
               all_volumes_are_ignored = FALSE;
               break;
             }
+
+          /* The volume may be an extended partition - we need to check all logical
+           * partitions as well (#597041)
+           */
+          volume_device = gdu_presentable_get_device (GDU_PRESENTABLE (volume));
+          if (volume_device != NULL)
+            {
+              if (g_strcmp0 (gdu_device_partition_get_scheme (volume_device), "mbr") == 0)
+                {
+                  gint type;
+
+                  type = strtol (gdu_device_partition_get_type (volume_device), NULL, 0);
+                  if (type == 0x05 || type == 0x0f || type == 0x85)
+                    {
+                      GList *enclosed_logical;
+                      GList *ll;
+
+                      enclosed_logical = gdu_pool_get_enclosed_presentables (pool, GDU_PRESENTABLE (volume));
+                      for (ll = enclosed_logical; ll != NULL && all_volumes_are_ignored; ll = ll->next)
+                        {
+                          GduPresentable *enclosed_logical_presentable = GDU_PRESENTABLE (ll->data);
+
+                          if (GDU_IS_VOLUME (enclosed_logical_presentable))
+                            {
+                              if (!should_volume_be_ignored (pool,
+                                                             GDU_VOLUME (enclosed_logical_presentable),
+                                                             fstab_mount_points))
+                                {
+                                  all_volumes_are_ignored = FALSE;
+                                }
+                            }
+                        }
+                      g_list_foreach (enclosed_logical, (GFunc) g_object_unref, NULL);
+                      g_list_free (enclosed_logical);
+                    }
+                }
+              g_object_unref (volume_device);
+            }
         }
     }
 
@@ -868,23 +935,26 @@ should_drive_be_ignored (GduPool *pool, GduDrive *d, GList *fstab_mount_points)
    *
    * b) the volumes of the drive are all ignored
    */
-  if (!has_volumes)
+  if (device != NULL)
     {
-      if (gdu_device_is_media_available (device))
-        ignored = TRUE;
-    }
-  else
-    {
-      if (all_volumes_are_ignored)
-        ignored = TRUE;
-    }
+      if (!have_volumes)
+        {
+          if (gdu_device_is_media_available (device))
+            ignored = TRUE;
+        }
+      else
+        {
+          if (all_volumes_are_ignored)
+            ignored = TRUE;
+        }
 
-  /* special case for audio discs: don't ignore the drive since we'll create
-   * a cdda:// mount for the drive
-   */
-  if (gdu_device_is_optical_disc (device) && gdu_device_optical_disc_get_num_audio_tracks (device) > 0)
-    {
-      ignored = FALSE;
+      /* special case for audio discs: don't ignore the drive since we'll create
+       * a cdda:// mount for the drive
+       */
+      if (gdu_device_is_optical_disc (device) && gdu_device_optical_disc_get_num_audio_tracks (device) > 0)
+        {
+          ignored = FALSE;
+        }
     }
 
  out:
